RegistryMapWriteGuard

Struct RegistryMapWriteGuard 

pub struct RegistryMapWriteGuard<'a, K, T>
where T: Send + Sync,
{ /* private fields */ }
Holds a write guard to the RegistryMap. See RegistryMap::write().

Implementations

Source

impl<'a, K, T> RegistryMapWriteGuard<'a, K, T>
where T: Send + Sync, K: Ord,

pub fn iter(&'a self) -> Iter<'a, K, T>

Acquires an iterator over the RegistryMap.

pub fn iter_mut(&mut self) -> IterMut<'_, K, T>

Acquires a mutable iterator over the RegistryMap.

pub fn get(&self, key: &K) -> Option<&T>

Acquires a reference to an element in the RegistryMap.

pub fn get_mut(&mut self, key: &K) -> Option<&mut T>

Acquires a mutable reference to an element in the RegistryMap.